==> juce-docs-7.0.9-1-armv7h.pkg.tar.xz: usr/share/doc/juce/html/search/variables_15.js <==
var searchData=
[
  ['v1_0',['v1',['../classIIRFilterBase.html#a75901c83e1f41a87d609e4752992f583',1,'IIRFilterBase']]],
  ['v2_1',['v2',['../classIIRFilterBase.html#a29cbf0fb32a6c2b1f9c1fdef7544a403',1,'IIRFilterBase']]],
  ['value_2',['value',['../structMidiMessage_1_1VariableLengthValue.html#a84b61b7773789f85e46f1ee6ec1cce7c',1,'MidiMessage::VariableLengthValue::value'],['../structMidiRPNMessage.html#ab0752b04a7c53924d33675bf769714c8',1,'MidiRPNMessage::value'],['../structEnumerated.html#ad1377346637d7a5d8f4606c593f280e3',1,'Enumerated::value'],['../structNamedValueSet_1_1NamedValue.html#af0fb4fb7cedc55a1918941733b84870f',1,'NamedValueSet::NamedValue::value'],['../structAtomic.html#ac07d27537523e75989dc1bd7ee978e5f',1,'Atomic::value'],['../structNamed.html#a3d8d584a8536b1e1cb1dc30d8f78c575',1,'Named::value'],['../structjuce_1_1dsp_1_1SIMDRegister.html#a780eee9fd525c64405503f11dba86d33',1,'juce::dsp::SIMDRegister::value'],['../structAccessibilityHandler_1_1Interfaces.html#a9233e8ebf0f02beecaaee9f693a69743',1,'AccessibilityHandler::Interfaces::value']]],
  ['valuefromtextfunction_3',['valueFromTextFunction',['../classSlider.html#a43c8424888dca4599d52304cb7496118',1,'Slider']]],
  ['valueswithlisteners_4',['valuesWithListeners',['../classValue_1_1ValueSource.html#ac6c18c9323cbda13d3e967c1b3c7b3cf',1,'Value::ValueSource']]],
  ['vblanklisteners_5',['vBlankListeners',['../classComponentPeer.html#a9f5f1ef144b3a7ec26312c049fc1175b',1,'ComponentPeer']]],
  ['vector_6',['vector',['../classQuaternion.html#aea2b69403fdef5dfde9c62c9aeac3925',1,'Quaternion']]],
  ['velocity_7',['velocity',['../structKeyboardComponentBase_1_1NoteAndVelocity.html#afbf3bd32ded75e7ec991bdb3349f46fc',1,'KeyboardComponentBase::NoteAndVelocity']]],
  ['version_8',['version',['../classPluginDescription.html#ad5d55de3c1ad1646e5cc49d04e5c41e8',1,'PluginDescription::version'],['../structjuce_1_1midi__ci_1_1Message_1_1Header.html#a4f0ac50c77fbb285bec85ddf3273075d',1,'juce::midi_ci::Message::Header::version']]],
  ['verticalfrequencyhz_9',['verticalFrequencyHz',['../structDisplays_1_1Display.html#a23d7b6b719679135768b641f81494f4b',1,'Displays::Display']]],
  ['vibrationpattern_10',['vibrationpattern',['../structPushNotifications_1_1Notification.html#a11d67737e656b05529698fe54c7bc5f1',1,'PushNotifications::Notification::vibrationPattern'],['../structPushNotifications_1_1Channel.html#a7b0ab8e6ce7d3fecb538cb74730ea818',1,'PushNotifications::Channel::vibrationPattern']]],
  ['violet_11',['violet',['../namespacejuce_1_1Colours.html#a88383ce98391919c3c2ef37c72cb61c0',1,'juce::Colours']]],
  ['voices_12',['voices',['../classMPESynthesiser.html#ae8ff04bfb33a5de6d649ed78bab37274',1,'MPESynthesiser::voices'],['../classSynthesiser.html#a260d964d6764a51b2315233e0bf76980',1,'Synthesiser::voices']]],
  ['voiceslock_13',['voicesLock',['../classMPESynthesiser.html#a7431fe9de7fd7b6216e5526406691e09',1,'MPESynthesiser']]],
  ['vst2_14',['vst2',['../structSpeakerMappings_1_1Mapping.html#a2645ca9d0b780b227d8f74b61e3061f8',1,'SpeakerMappings::Mapping']]]
];

==> juce-docs-7.0.12-1-armv7h.pkg.tar.xz: usr/share/doc/juce/html/search/variables_15.js <==
var searchData=
[
  ['v1_0',['v1',['../classIIRFilterBase.html#a75901c83e1f41a87d609e4752992f583',1,'IIRFilterBase']]],
  ['v2_1',['v2',['../classIIRFilterBase.html#a29cbf0fb32a6c2b1f9c1fdef7544a403',1,'IIRFilterBase']]],
  ['value_2',['value',['../structMidiMessage_1_1VariableLengthValue.html#a84b61b7773789f85e46f1ee6ec1cce7c',1,'MidiMessage::VariableLengthValue::value'],['../structMidiRPNMessage.html#ab0752b04a7c53924d33675bf769714c8',1,'MidiRPNMessage::value'],['../structEnumerated.html#ad1377346637d7a5d8f4606c593f280e3',1,'Enumerated::value'],['../structNamedValueSet_1_1NamedValue.html#af0fb4fb7cedc55a1918941733b84870f',1,'NamedValueSet::NamedValue::value'],['../structAtomic.html#ac07d27537523e75989dc1bd7ee978e5f',1,'Atomic::value'],['../structNamed.html#a3d8d584a8536b1e1cb1dc30d8f78c575',1,'Named::value'],['../structjuce_1_1dsp_1_1SIMDRegister.html#a780eee9fd525c64405503f11dba86d33',1,'juce::dsp::SIMDRegister::value'],['../structAccessibilityHandler_1_1Interfaces.html#a9233e8ebf0f02beecaaee9f693a69743',1,'AccessibilityHandler::Interfaces::value']]],
  ['valuefromtextfunction_3',['valueFromTextFunction',['../classSlider.html#a067bba64c451808dc3d02cd0e4722c92',1,'Slider']]],
  ['valueswithlisteners_4',['valuesWithListeners',['../classValue_1_1ValueSource.html#ac6c18c9323cbda13d3e967c1b3c7b3cf',1,'Value::ValueSource']]],
  ['vblanklisteners_5',['vBlankListeners',['../classComponentPeer.html#a9f5f1ef144b3a7ec26312c049fc1175b',1,'ComponentPeer']]],
  ['vector_6',['vector',['../classQuaternion.html#aea2b69403fdef5dfde9c62c9aeac3925',1,'Quaternion']]],
  ['velocity_7',['velocity',['../structKeyboardComponentBase_1_1NoteAndVelocity.html#afbf3bd32ded75e7ec991bdb3349f46fc',1,'KeyboardComponentBase::NoteAndVelocity']]],
  ['version_8',['version',['../classPluginDescription.html#ad5d55de3c1ad1646e5cc49d04e5c41e8',1,'PluginDescription::version'],['../structjuce_1_1midi__ci_1_1Message_1_1Header.html#a4f0ac50c77fbb285bec85ddf3273075d',1,'juce::midi_ci::Message::Header::version']]],
  ['verticalfrequencyhz_9',['verticalFrequencyHz',['../structDisplays_1_1Display.html#a23d7b6b719679135768b641f81494f4b',1,'Displays::Display']]],
  ['vibrationpattern_10',['vibrationPattern',['../structPushNotifications_1_1Notification.html#a11d67737e656b05529698fe54c7bc5f1',1,'PushNotifications::Notification::vibrationPattern'],['../structPushNotifications_1_1Channel.html#a7b0ab8e6ce7d3fecb538cb74730ea818',1,'PushNotifications::Channel::vibrationPattern']]],
  ['violet_11',['violet',['../namespacejuce_1_1Colours.html#a88383ce98391919c3c2ef37c72cb61c0',1,'juce::Colours']]],
  ['voices_12',['voices',['../classMPESynthesiser.html#ae8ff04bfb33a5de6d649ed78bab37274',1,'MPESynthesiser::voices'],['../classSynthesiser.html#a260d964d6764a51b2315233e0bf76980',1,'Synthesiser::voices']]],
  ['voiceslock_13',['voicesLock',['../classMPESynthesiser.html#a7431fe9de7fd7b6216e5526406691e09',1,'MPESynthesiser']]],
  ['vst2_14',['vst2',['../structSpeakerMappings_1_1Mapping.html#a2645ca9d0b780b227d8f74b61e3061f8',1,'SpeakerMappings::Mapping']]]
];
